C> @file eiram_example.f90
C> Example of usage for EIRAM
C> @author Vladislav Kotov, v.kotov@fz-juelich.de
      program eiram_example 
      use eiram

      integer :: err,id,k,N,M
      integer,parameter :: L=4
      real(eiram_dp) :: Eb(L)=(/1,10,100,1000/),
     r                  Ti(L)=(/1,10,100,1000/), 
     r                  ne(L)=(/1e15,1e14,1e13,1e12/),
     r                  sigma(L),rate(L),lnE
      real(eiram_dp),allocatable :: B(:,:) 

      intrinsic :: log,exp

C #################################################################
C  Calculation of cross-section (depend only on energy)
C #################################################################

C     load HYDHEL
      call eiram_load('../data/','HYDHEL',err) 
      if(err.ne.0) STOP "ERROR while loading HYDHEL" 

C     take Id of reaction H.1 3.1.8  - 
C     - cross-section of the hydrogen charge-exchange 
      id=eiram_get_id('HYDHEL','H.1','3.1.8',err)
      if(err.ne.0) STOP "ERROR while looking for HYDHEL H.1 3.1.8" 

C     calculate cross-section as a function of beam energy Eb,
C     use vector function
      call eiram_calc1(sigma,id,log(Eb),err)
      if(err.ne.0) STOP "ERROR while calculating cross-section" 
      sigma=exp(sigma) 

C     ... calculate cross-section, use fast scalar function,
C     print results
      write(*,*)
      write(*,*) 'HYDHEL H.1 3.1.8'
      write(*,*) ' sigma [cm-3], E [eV]'
      do k=1,L
       sigma(k)=eiram_calc1_fast(id,log(Eb(k)))
       write(*,'(1X,E10.2,1X,F7.1)') sigma(k),Eb(k)
      end do      

C #################################################################
C  Calculation heavy particle collision rate 
C  (depend on both energy a background temperature)
C #################################################################

C     take Id of reaction H.3 3.1.8  - 
C     - collision rate of the hydrogen charge-exchange
      id=eiram_get_id('HYDHEL','H.3','3.1.8',err)
      if(err.ne.0) STOP "ERROR while looking for HYDHEL H.3 3.1.8" 

C     calculate fit coefficients reduced over second variable
      call eiram_get_order(N,M,id,err)
      if(err.ne.0) STOP "ERROR detected in  eiram_get_order" 
      allocate(B(N+1,L))
      call eiram_calc12(B,id,log(Ti),err)
      if(err.ne.0) STOP "ERROR while calculating fit coefficients" 

C     calculate collision rates for E=Eb(2), print results       
      lnE=log(Eb(2))
      write(*,*)
      write(*,'(1X,A,F5.1,A)') 'HYDHEL H.3 3.1.8, E=',Eb(2),' [eV]'
      write(*,*) ' rate [cm3/s], Ti [eV]'
      do k=1,L
       rate(k)=exp(eiram_fit(B(:,k),N,lnE))
       write(*,'(1X,E10.2,1X,F7.1)') rate(k),Ti(k)
      end do   
      write(*,*)
      deallocate(B)

C #################################################################
C  Calculation of density dependent electron impact rate
C #################################################################

C     Append AMJUEL to already loaded HYDHEL
      call eiram_load('../data/','AMJUEL',err) 
      if(err.ne.0) STOP "ERROR while loading AMJUEL" 

C     take Id of reaction H.4 2.1.5 - 
C     - ionization rate of hydrogen atoms 
      id=eiram_get_id('AMJUEL','H.4','2.1.5',err)
      if(err.ne.0) STOP "ERROR while looking for AMJUEL H.4 2.1.5" 

C     calculate collision rates for pairs (ne,Te=Ti)
C     Don't forget to divide density in cm-3 by 1e8!
      call eiram_calc2(rate,id,log(ne/1e8),log(Ti),err)
      if(err.ne.0) STOP "ERROR while calculating collision rates" 

C     print results
      write(*,*)
      write(*,*) 'AMJUEL H.4 2.1.5'
      write(*,*) ' rate [cm3/s], ne [cm-3], Te [eV]'
      do k=1,L
       write(*,'(1X,2E10.2,1X,F7.1)') rate(k),ne(k),Ti(k)
      end do
      write(*,*)

C     deallocate memory
      call eiram_deallocate(err)

      STOP "EIRAM_EXAMPLE COMPLETED"

      end program eiram_example 
