%
% Calculate reaction rates and cross-sections described by polynomial fit formulas 
% (interface to fortran module EIRAM)
%  
%  [Y1 Y2 .. ] = eiram(X1, [X2,] name, type, index, [path])
%
%   Y1, Y2 ... : vectors or matrices with the results,
%                each Y1, Y2 ..., corresponds to one reaction defined in INDEX,
%                each column in Y1, Y2 ... corresponds to one value of X1       
%   X1    : row vector, first argument of the fit
%   X2    : optional,  column vector, second argument of the fit
%   name  : string, name of the file with the data-set ('HYDHEL', 'AMJUEL' etc.)
%   type  : string, type of the reaction ('H.1','H.3','H.4' etc.)
%   index : array of strings, index of the reaction ('3.1.8', '2.1.5' etc.)
%   path  : optional, string, complete path to the file defined by NAME,
%           if PATH is omitted than it is assumed that the data-set is in the current folder           
%
%  Units: energy and temperature in [eV], density in [cm^-3],
%         cross sections in cm^2, collision rates in cm^3/s,    
%         energy loss rates in cm^3/s*eV 
%
%  Examples:
%  % Charge-exchange H + p, Ebeam=10 eV 
%    svcx = eiram(10,[1:100],'HYDHEL','H.3','3.1.8');
%
%  % Momentum transfer cross-sections for elastic collisions p+H, p+He, p+H2
%   [sel_D sel_He sel_D2] = eiram([0.1:10],'AMJUEL','H.1',['0.1D'; '0.2D'; '0.3D'],'.../eiram/data/');
%
%  % Ionization rate of H atoms, electron density 1e12 cm-3 and 1e14 cm-3 
%    svi = eiram([1e12 1e14],[0.1:0.1:10 10+1:1:100],'AMJUEL','H.4','2.1.5');
%
%
%  In case of problems, run matlab without gui (matlab -nodisplay) or try 'clear mex'.
%
% WARNING: messages printed by EIRAM appear only on the console (not in the Matlab GUI window)


%    Copyright (c) 2016  Forschungszentrum Juelich GmbH
%                        Markus Brenneis, Vladislav Kotov 
%
%    This file is part of EIRAM.
%
%    EIRAM is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    EIRAM is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with EIRAM.  If not, see <http://www.gnu.org/licenses/>.
%
