%
% Tests for Matlab/Octave interface
%

%    Copyright (c) 2016  Forschungszentrum Juelich GmbH
%                        Markus Brenneis, Vladislav Kotov 
%
%    This file is part of EIRAM.
%
%    EIRAM is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    EIRAM is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with EIRAM.  If not, see <http://www.gnu.org/licenses/>.
%

addpath('../src/matlab');

global failures;
global REL_TOL;
failures = 0;
REL_TOL = 1e-4; %relative accuracy to compare expected and calculated values

%
% tests with wrong syntax to make sure that memory is deallocated properly in case of errors
%
try
    y = eiram([0.1 10 20], [19], 'HYDHEL', 'H.2', '2.1.5','../data/');
catch
end
try
    y = eiram([1e2, 1e3], 'AMJUEL', 'H.4', '2.1.5','../data/');
catch
end
try
    y = eiram([0.1 10 20], 'AMJUEL', 'H.222', '2.1.5','../data/');
catch
end
try
    y = eiram([0.1 10 20], '/__foo_HYDHEL', 'H.2', '2.1.5','../data/');
catch
end
try
    y = eiram([0.1 10 20], 'HYDHEL', 'H.2', '2.1f5','../data/');
catch
end
try
    y = eiram([0.1 10 20], 'HYDHEL', 'H.2');
catch
end
try
    y = eiram('HYDHEL', 'H.2', '2.1.5','../data/');
catch
end
try
    y = eiram([0.1 10 20], [19], 'HYDHEL', 'H.2');
catch
end

try
    expected = [6.201607490833009e-15; 0.051725617127413e-7; 0.139709863123599e-7];
    y = eiram([1 10 20], 'HYDHELvk', 'H.2', '2.1.5','../data/');
    matlab_passed(y, expected);
    
    expected = [4.904897322289924d-14; 9.954471496437615d-09; 4.738209685016329d-08; 2.907993073331902d-08];
    y= eiram(1e14, [1e0 1e1 1e2 1e3], 'AMJUELvk', 'H.4', '2.1.5','../data/');
    matlab_passed(y, expected); 
  
    expected14 = [4.904897322289924d-14; 9.954471496437615d-09; 4.738209685016329d-08; 2.907993073331902d-08];
    expected12 = [9.766957551131717e-15; 6.342635942226082e-09; 3.575192886400299e-08; 2.319666570822714e-08]; 
    y= eiram([1e14 1e12], [1e0 1e1 1e2 1e3], 'AMJUELvk', 'H.4', '2.1.5','../data/');
    matlab_passed(y(:,1), expected14); 
    matlab_passed(y(:,2), expected12); 

    expected = [6.201607490833009e-15; 0.051725617127413e-7; 0.139709863123599e-7];
    [y1 y2] = eiram([1 10 20], 'HYDHELvk', 'H.2', ['2.1.5'; '2.1.5'],'../data/');
    matlab_passed(y1, expected);
    matlab_passed(y2, expected);

    expected14 = [4.904897322289924d-14; 9.954471496437615d-09; 4.738209685016329d-08; 2.907993073331902d-08];
    expected12 = [9.766957551131717e-15; 6.342635942226082e-09; 3.575192886400299e-08; 2.319666570822714e-08]; 
    [y1 y2]= eiram([1e12 1e14], [1e0 1e1 1e2 1e3], 'AMJUELvk', 'H.4', ['2.1.5'; '2.1.5'],'../data/');   
    matlab_passed(y1(:,1), expected12); 
    matlab_passed(y1(:,2), expected14); 
    matlab_passed(y2(:,1), expected12); 
    matlab_passed(y2(:,2), expected14); 

    if(failures == 0)
        fprintf('\nPASSED\n')
        quit(0)
    else
        fprintf('\nFAILED\n')
        quit(1)
    end
catch e
    if(exist('OCTAVE_VERSION', 'builtin') == 0)
        getReport(e, 'basic') % matlab
    else
        lasterror().message   % octave
    end
    fprintf('\nFAILED\n')
    quit(-1)
end
