!> @file json.f90
!> Auxiliary functions for converting of Fortran data structures into JSON strings.
!> @authors Markus Brenneis Markus.Brenneis@uni-duesseldorf.de,
!>          Vladislav Kotov v.kotov@fz-juelich.de (contact person)
!>

!    Copyright (c) 2016  Forschungszentrum Juelich GmbH
!                        Markus Brenneis, Vladislav Kotov 
!
!    This file is part of EIRAM.
!
!    EIRAM is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    (at your option) any later version.
!
!    EIRAM is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with EIRAM.  If not, see <http://www.gnu.org/licenses/>.
!

    module json
    
    implicit none

    public :: eiram_json_getArrayAsJson,eiram_json_jsonEscape,eiram_json_writeJsonStringProperty

    contains

    !> Return a JSON array string (ie. "[…]") with the elements of the given array \ref arr
    function eiram_json_getArrayAsJson(arr, length, itol)
        !> the array which is converterted to a json array string
        real(8), dimension(:), intent(in) :: arr
        !> the (trimmed) length of the returned string
        integer, intent(out) :: length
        !> Number of significant digits in the output
        integer,intent(in) :: itol
        character(size(arr)*(itol+9)+2) :: eiram_json_getArrayAsJson
        integer :: c, i, lfld
        character(16) :: frm

        eiram_json_getArrayAsJson = " "
        eiram_json_getArrayAsJson(1:1) = "["
        c = 2
        lfld=itol+8
        write(frm,'(A3,i2.2,A1,i2.2,A3)') '(Es',lfld,'.',itol,'E3)'
        do i = 1, size(arr)
            if(i > 1) then
                eiram_json_getArrayAsJson(c:c) = ","
                c = c+1
            end if
            if(abs(arr(i)) < huge(1d0)) then
                write(eiram_json_getArrayAsJson(c:c+lfld),frm) arr(i)
            else
                write(eiram_json_getArrayAsJson(c:c+lfld), '(A)') "null"
            end if
            c = c+lfld
        end do
        eiram_json_getArrayAsJson(c:c) = "]"
        length = len_trim(eiram_json_getArrayAsJson)
    end function eiram_json_getArrayAsJson
    
    !> Return the input string where »\« and »"« are escaped with backslashes.
    function eiram_json_jsonEscape(str, length)
        !> the string which will be escaped
        character(*), intent(in) :: str
        !> the (trimmed) length of the escaped string
        integer, intent(out) :: length
        character(len_trim(str)*2) ::  eiram_json_jsonEscape
        integer :: s
        length = 1
        forEachChar: do s = 1, len_trim(str)
            if(str(s:s) == '"') then
                 eiram_json_jsonEscape(length:length+1) = '\' 
                length = length + 2
            else if(str(s:s) == '\') then
                eiram_json_jsonEscape(length:length+1) = '\\'
                length = length + 2
            else
                 eiram_json_jsonEscape(length:length) = str(s:s)
                length = length + 1
            end if
        end do forEachChar
         eiram_json_jsonEscape(length:) = " "
        length = length - 1
    end function eiram_json_jsonEscape
    
    !> Write a pair of the JSON property-(string-)values into a string, including leading comma
    subroutine eiram_json_writeJsonStringProperty(name, value, jsonString, ind)
        !> the name of the property
        character(*), intent(in) :: name
        !> the value of the property; the value is assumed not to be escaped
        character(*), intent(in) :: value
        !> the string to which the property is written
        character(*), intent(inout) :: jsonString
        !> the index of the string where the value is written; 
        !> after the call, the index is positioned after the last character written
        integer, intent(inout) :: ind
        integer :: length
        intrinsic trim,len_trim,max
        jsonString(ind:) = ',"'//trim(eiram_json_jsonEscape(trim(name), length))//'":"'
        ind = ind+length+5
        jsonString(ind:) = trim(eiram_json_jsonEscape(trim(value), length))
        ind = ind+length
        jsonString(ind:ind) = '"'
        ind = ind+1
    end subroutine eiram_json_writeJsonStringProperty

    end module json
